==> setParam-2.0-b130411.zip: setParam-2.0-b130411/message/setParam-text.tcl <==
#
# setParamC̃gbvj[
#
set t(file)                      "t@C"
set t(file,choosesaveDir)        "ۑtH_̕ύX"
set t(file,readParamFile)        "p[^̓ǂݍ (Ctrl+o)"
set t(file,saveParamFile)        "p[^̕ۑ     (Ctrl+s)"
set t(file,mergeParamFile)       "ʂ̌p[^}[W"
set t(file,readSettings)         "t@Cw肵ēǂݍ"
set t(file,saveSettings)         "݂̐ݒt@Cɕۑ"
set t(file,readUstFile)          "ustt@CǂŕҏWΏۂŏɍi"
set t(file,dirHistory)           "ŋߎgtH_J"
set t(file,pDirHistory)          "ŋߎgetH_J"

set t(file,test)                 "ʏgȂ@\"
set t(file,test,makeRecList)     "ۑtH_wavt@C甭Xg쐬"
set t(file,test,makeRecList,msg) "XgA^CvXgXV܂"
set t(file,test,readRecList)     "Xg̓ǂݍ"
set t(file,test,saveRecList)     "Xg̕ۑ"
set t(file,test,readTypeList)    "^CvXg̓ǂݍ"
set t(file,Exit)                 "I"

set t(edit)                      "ҏW"
set t(edit,tk_tableCopy)         "Rs[   (Ctrl+c)"
set t(edit,pasteCell)            "\t (Ctrl+v)"
set t(edit,searchParam)          "     (Ctrl+f)"
set t(edit,doSearchParam1)       " (Ctrl+g, Ctrl+n)"
set t(edit,doSearchParam0)       "O (Ctrl+G, Ctrl+N)"
set t(edit,changeCell)           "I𒆂͈̔͂̒lꊇύX (Ctrl+m)"
set t(edit,estimateParam)        "p[^(PƉp)"
set t(edit,zeroCross)            "ep[^̃[NX␳"
set t(edit,copyWithSpace)        "󔒋؂Łc"
set t(edit,copyCellWithSpace)    "Rs["
set t(edit,pasteCellWithSpace)   "\t"

set t(show)                      "\"
set t(show,showSpec)             "XyNg\"
set t(show,showpow)              "p[\"
set t(show,showf0)               "F0\"
set t(show,pitchGuide)           "\"
set t(show,zoomTitle)            "̊g"
set t(show,timeAxis)             "Ԏ"
set t(show,timeAxisSec)          "bP"
set t(show,timeAxisBar)          "ߒP"

set t(option)                    "IvV"
set t(option,gui)                "}EXAL[̐ݒ"
set t(option,S)                  "}EXōuN𓮂ƂA"
set t(option,S,1)                "p[^ꏏɓđΓIȈʒu֌WۂB"
set t(option,S,2)                "p[^͓AuN݂̂𓮂B"
set t(option,E)                  "EuNl̕\@"
set t(option,E,1)                "t@C̎(̒lŕ\BUTAU v0.2.43ȑOp)"
set t(option,E,2)                "uN̎(̒lŕ\BUTAU v0.2.45betaňȍ~p)"
set t(option,P)                  "}EXŐs𓮂ƂA"
set t(option,P,1)                "p[^ꏏɓđΓIȈʒu֌WۂB"
set t(option,P,2)                "p[^͓Aŝ݂𓮂B"
set t(option,minusO)             "I[o[bv𕉂ɂĂǂ"
set t(option,blankBroom)         "EuN̈ړ\͈͂𑼃p[^D悷"
set t(option,cutBlank)           "F9ōEuN̗g`Jbg"
set t(option,timingAdjMode)      "^C~O␳[h"
#set t(option,unusual)            "{gȂ@\"
#set t(option,removeDC)           "^DC"
#set t(option,rec)                "^@\g"
set t(option,uttTimingSettings)  "^C~O`FbN̐ݒ"
set t(option,ioSettings)         "I[fBII/Oݒ"
set t(option,settings)           "ڍאݒ"
set t(option,setPlayRange)       "w͈͍Đ̐ݒ"

set t(tool)                      "c["
set t(tool,auto)                 "p[^̎"
set t(tool,auto,estimateParam)       "PƉ̎"
set t(tool,auto,autoParamEstimation) "PƉ̎肻2(Oc[FԂ)"
set t(tool,auto,genParam)            "A̎"
set t(tool,auto,plugin)              "vOC"
set t(tool,removeDCall)          "DC̈ꊇ"
set t(tool,addUnderScore)        "wavt@C̐擪Ɂu_vǉ(Ap)"
set t(tool,addUnderScore2)       "wavt@C(gt@C)̐擪Ɂu_vǉ(Ap)"
set t(tool,test)                 "eXg"
set t(tool,cutWav)               "wav̗[ꊇJbg"
set t(tool,changeAlias)          "GCAXꊇύX"
set t(tool,convertMonoAll)       "wavt@C̈ꊇm"
set t(tool,wav)                  "wavt@C̈ꊇҏW"
set t(tool,zeroCross)            "ep[^̃[NX␳"
set t(tool,runExplorer)          "ۑtH_GNXv[ŊJ"

set t(tool,finish)                 "dグA⊮pc["
set t(tool,finish,aliasComplement) "Aoto.iniɖGCAXTAPƉŕ⊮"
set t(tool,finish,woComplement)    "uvꍇuvŕ⊮"

set t(help)                      "wv"
set t(help,onlineHelp)           "IC}jA"
set t(help,Version)              "o[W"

#
# setParamĈ̑̃x
#
set t(.saveDir.midashi)     "ۑtH_F"

==> setParam-3.0-b140121.zip: setParam-3.0-b140121/message/setParam-text.tcl <==
#
# setParamC̃gbvj[
#
set t(file)                      "t@C"
set t(file,choosesaveDir)        "ۑtH_̕ύX"
set t(file,readParamFile)        "p[^̓ǂݍ (Ctrl+o)"
set t(file,saveParamFile)        "p[^̕ۑ     (Ctrl+s)"
set t(file,mergeParamFile)       "ʂ̌p[^}[W"
set t(file,readSettings)         "t@Cw肵ēǂݍ"
set t(file,saveSettings)         "݂̐ݒt@Cɕۑ"
set t(file,readUstFile)          "ustt@CǂŕҏWΏۂŏɍi"
set t(file,dirHistory)           "ŋߎgtH_J"
set t(file,pDirHistory)          "ŋߎgetH_J"

set t(file,test)                 "ʏgȂ@\"
set t(file,test,makeRecList)     "ۑtH_wavt@C甭Xg쐬"
set t(file,test,makeRecList,msg) "XgA^CvXgXV܂"
set t(file,test,readRecList)     "Xg̓ǂݍ"
set t(file,test,saveRecList)     "Xg̕ۑ"
set t(file,test,readTypeList)    "^CvXg̓ǂݍ"
set t(file,Exit)                 "I"

set t(edit)                      "ҏW"
set t(edit,tk_tableCopy)         "Rs[   (Ctrl+c)"
set t(edit,pasteCell)            "\t (Ctrl+v)"
set t(edit,searchParam)          "     (Ctrl+f)"
set t(edit,doSearchParam1)       " (Ctrl+g, Ctrl+n)"
set t(edit,doSearchParam0)       "O (Ctrl+G, Ctrl+N)"
set t(edit,changeCell)           "I𒆂͈̔͂̒lꊇύX (Ctrl+m)"
set t(edit,estimateParam)        "p[^(PƉp)"
set t(edit,zeroCross)            "ep[^̃[NX␳"
set t(edit,copyWithSpace)        "󔒋؂Łc"
set t(edit,copyCellWithSpace)    "Rs["
set t(edit,pasteCellWithSpace)   "\t"
set t(edit,duplicateEntp)        "s𕡐  (Ctrl+i)"
set t(edit,deleteEntp)           "s폜  (Ctrl+d)"

set t(show)                      "\"
set t(show,showSpec)             "XyNg\"
set t(show,showpow)              "p[\"
set t(show,showf0)               "F0\"
set t(show,pitchGuide)           "\"
set t(show,zoomTitle)            "̊g"
set t(show,timeAxis)             "Ԏ"
set t(show,timeAxisSec)          "bP"
set t(show,timeAxisBar)          "ߒP"

set t(option)                    "IvV"
set t(option,gui)                "}EXAL[̐ݒ"
set t(option,S)                  "}EXōuN𓮂ƂA"
set t(option,S,1)                "p[^ꏏɓđΓIȈʒu֌WۂB"
set t(option,S,2)                "p[^͓AuN݂̂𓮂B"
set t(option,E)                  "EuNl̕\@"
set t(option,E,1)                "t@C̎(̒lŕ\BUTAU v0.2.43ȑOp)"
set t(option,E,2)                "uN̎(̒lŕ\BUTAU v0.2.45betaňȍ~p)"
set t(option,P)                  "}EXŐs𓮂ƂA"
set t(option,P,1)                "p[^ꏏɓđΓIȈʒu֌WۂB"
set t(option,P,2)                "p[^͓Aŝ݂𓮂B"
set t(option,minusO)             "I[o[bv𕉂ɂĂǂ"
set t(option,blankBroom)         "EuN̈ړ\͈͂𑼃p[^D悷"
set t(option,cutBlank)           "F9ōEuN̗g`Jbg(PƉ@\)"
set t(option,timingAdjMode)      "^C~O␳[h"
#set t(option,unusual)            "{gȂ@\"
#set t(option,removeDC)           "^DC"
#set t(option,rec)                "^@\g"
set t(option,uttTimingSettings)  "^C~O`FbN̐ݒ(Đ=F8)"
set t(option,ioSettings)         "I[fBII/Oݒ"
set t(option,settings)           "ڍאݒ"
set t(option,setPlayRange)       "w͈͍Đ̐ݒ"
set t(option,synTestWindow)      "eXg̐ݒ(Đ=F10)"
set t(option,clickPlayRangeMode)      "ʃNbNŋߖTp[^ԂĐ"

set t(tool)                      "c["
set t(tool,auto)                 "p[^̎"
set t(tool,auto,estimateParam)       "PƉ̎"
set t(tool,auto,autoParamEstimation) "PƉ̎肻2(Oc[FԂ)"
set t(tool,auto,genParam)            "A̎"
set t(tool,auto,plugin)              "vOC"
set t(tool,removeDCall)          "DC̈ꊇ"
set t(tool,addUnderScore)        "wavt@C̐擪Ɂu_vǉ(Ap)"
set t(tool,addUnderScore2)       "wavt@C(gt@C)̐擪Ɂu_vǉ(Ap)"
set t(tool,test)                 "eXg"
set t(tool,cutWav)               "wav̗[ꊇJbg"
set t(tool,changeAlias)          "GCAXꊇύX"
set t(tool,convertMonoAll)       "wavt@C̈ꊇm"
set t(tool,wav)                  "wavt@C̈ꊇҏW"
set t(tool,zeroCross)            "ep[^̃[NX␳"
set t(tool,runExplorer)          "ۑtH_GNXv[ŊJ"

set t(tool,finish)                 "dグA⊮pc["
set t(tool,finish,aliasComplement) "Aoto.iniɖGCAXTAPƉŕ⊮"
set t(tool,finish,woComplement)    "uvꍇuvŕ⊮"
set t(tool,sort)                   "p[^ꗗ̕ёւ"
set t(tool,sort,sortByVowel)       "ɕёւ"
set t(tool,sort,sortByFID)         "wavt@Cɕёւ"

set t(help)                      "wv"
set t(help,onlineHelp)           "IC}jA"
set t(help,Version)              "o[W"

#
# setParamĈ̑̃x
#
set t(.saveDir.midashi)     "ۑtH_F"
